from setuptools import setup, find_packages

setup(name='necroplankton',
      version='0.0.2',
      description='tool set',
      author='necroplankton',
      author_email='necroplankton@rainy.me',
      classifiers=[
          'Development Status :: 4 - Beta',
          'Intended Audience :: Developers',
          'Programming Language :: Python :: 3.6',
      ],
      python_requires='>=3.6',
      license="MIT Licence",
      packages=find_packages(),
      install_requires=["requests"]
      )



import sys, os

__p = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
if __p not in sys.path:
    sys.path.insert(0, __p)

from .lib import  fetch as __fetch
from .lib import out as __out

__author__ = 'necroplankton'


fetch = __fetch.Fetch()
output = __out.Put()

if __name__ == '__main__':
    #fetch.img('https://cloud.rainy.me/beach.jpg')
    output.json({})